src/c/so3_error.h File Reference

# so3_error.h File Reference

`#include <stdio.h>`

Go to the source code of this file.

## Defines
#define | SO3_ERROR_GENERIC(comment)
#define | SO3_ERROR_MEM_ALLOC_CHECK(pointer)

## Detailed Description

Error macros used in SO3 package.

Author:
  Martin Büttner
  Jason McEwen

Definition in file so3_error.h.

## Define Documentation

#define SO3_ERROR_GENERIC | ( | comment |  | ) |

Value:

    {                                                                       \
      printf("ERROR: %s.\n", comment);                                      \
      printf("ERROR: %s <%s> %s %s %s %d.\n",                               \
             "Occurred in function",                                        \
               __PRETTY_FUNCTION__,                                         \
               "of file", __FILE__,                                         \
               "on line", __LINE__);                                        \
      exit(1);                                                              \
    }

Definition at line 19 of file so3_error.h.

Referenced by so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_sampling_a2alpha(), so3_sampling_b2beta(), so3_sampling_elmn2ind(), so3_sampling_elmn2ind_real(), so3_sampling_flmn_size(), so3_sampling_ind2elmn(), so3_sampling_ind2elmn_real(), so3_sampling_n(), so3_sampling_nalpha(), so3_sampling_nbeta(), so3_sampling_weight(), so3_test_gen_flmn_complex(), and so3_test_gen_flmn_real().

#define SO3_ERROR_MEM_ALLOC_CHECK | ( | pointer |  | ) |

Value:

    if(pointer == NULL) {                                                   \
        SO3_ERROR_GENERIC("Memory allocation failed")                       \
      }

Definition at line 30 of file so3_error.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), and so3_core_inverse_via_ssht_real().